@@ -16,8 +16,9 @@ use strict;
 use warnings;
 
 use Dancer ':script';
-use Expect;
+use Data::Printer;
 use Moo;
+use Expect;
 
 =head1 PUBLIC METHODS
 
@@ -28,14 +29,12 @@ use Moo;
 Retrieve ARP entries from device. C<$host> is the hostname or IP address
 of the device. C<$ssh> is a Net::OpenSSH connection to the device.
 
-Returns a list of hashrefs in the format C<{ mac => MACADDR, ip => IPADDR }>.
-
-=back
+Returns an array of hashrefs in the format { mac => MACADDR, ip => IPADDR }.
 
 =cut
 
 sub arpnip{
-    my ($self, $hostlabel, $ssh, $args) = @_;
+    my ($self, $hostlabel, $ssh, @args) = @_;
 
     debug "$hostlabel $$ arpnip()";
 
